aboutsummaryrefslogtreecommitdiff
path: root/libbb/ask_confirmation.c
diff options
context:
space:
mode:
authorDenys Vlasenko <vda.linux@googlemail.com>2018-04-07 15:08:12 +0200
committerDenys Vlasenko <vda.linux@googlemail.com>2018-04-07 15:08:12 +0200
commit77cb6b99a436c20bb171e6cdad7b8b8b5ce3692c (patch)
treed00b5b460baa99be5547a2236790dbea31f90a5d /libbb/ask_confirmation.c
parent2f094ae82106e91cb210e79ddc2e5285377b549e (diff)
downloadbusybox-77cb6b99a436c20bb171e6cdad7b8b8b5ce3692c.tar.gz
libbb: rename bb_ask -> bb_ask_noecho, bb_ask_confirmation -> bb_ask_y_confirmation
Signed-off-by: Denys Vlasenko <vda.linux@googlemail.com>
Diffstat (limited to 'libbb/ask_confirmation.c')
-rw-r--r--libbb/ask_confirmation.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libbb/ask_confirmation.c b/libbb/ask_confirmation.c
index 6fbed89f4..ccd983c29 100644
--- a/libbb/ask_confirmation.c
+++ b/libbb/ask_confirmation.c
@@ -1,6 +1,6 @@
/* vi: set sw=4 ts=4: */
/*
* bb_ask_confirmation implementation for busybox
*
* Copyright (C) 2003 Manuel Novoa III <mjn3@codepoet.org>
*
@@ -11,7 +11,7 @@
/* Read a line from stdin. If the first non-whitespace char is 'y' or 'Y',
* return 1. Otherwise return 0.
*/
-int FAST_FUNC bb_ask_confirmation(void)
+int FAST_FUNC bb_ask_y_confirmation(void)
{
char first = 0;
int c;
@@ -1,6 +1,6 @@
/* vi: set sw=4 ts=4: */
/*
- * bb_ask_confirmation implementation for busybox
+ * bb_ask_y_confirmation implementation for busybox
*
* Copyright (C) 2003 Manuel Novoa III <mjn3@codepoet.org>